==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/chest/dialogs_es.lua <==

dialogId("tru-v-nasly", "font_big", "So we have finally found it.")
dialogStr("Así que finalmente lo hemos encontrado.")


dialogId("tru-m-co", "font_small", "What?")
dialogStr("¿Qué?")


dialogId("tru-v-poklad", "font_big", "Captain Silver`s treasure, of course.")
dialogStr("El tesoro del Capitán Silver, por supuesto.!")


dialogId("tru-v-gral", "font_big", "The Holy Grail, of course.")
dialogStr("El Santo Grial, por supuesto.")


dialogId("tru-v-vkupe", "font_big", "It`s neatly in one place: the treasure and the Grail.")
dialogStr("Están cuidadosamente en un mismo lugar: el tesoro y el Grial.")


dialogId("tru-m-zrada", "font_small", "I think it`s much too easy to be true.")
dialogStr("Creo que es demasiado fácil para ser verdad.")


dialogId("tru-m-oznamit", "font_small", "I think that if it really was our goal, the game would let the player know.")
dialogStr("Pienso que si realmente era nuestra meta, el juego dejaría que el jugador lo supiera.")


dialogId("tru-v-stacit", "font_big", "But I have let them know. That could be enough.")
dialogStr("Pero yo tengo que hacerles saber. Eso podría ser suficiente.")


dialogId("tru-m-zpochybnit", "font_small", "But I have casted doubts on it. This could confuse them.")
dialogStr("Pero he dicho las dudas a propósito. Esto los podría confundir.")


dialogId("tru-v-nejspis", "font_big", "Well, all right. PROBABLY this is not what we are looking for.")
dialogStr("Bueno, está bien. PROBABLEMENTE esto no es lo que andamos buscando.")


dialogId("tru-m-nejistota", "font_small", "That's better. There remains a bit of uncertainty.")
dialogStr("Eso es mejor. Le resta un poco de incertidumbre.")


dialogId("tru-m-truhla0", "font_small", "Couldn`t we close that chest?")
dialogStr("¿Podríamos acercar ese cofre?")


dialogId("tru-m-truhla1", "font_small", "What if we try to close that chest?")
dialogStr("¿Y si tratamos de acercar ese cofre?")


dialogId("tru-v-truhla0", "font_big", "It would be much easier with the chest closed.")
dialogStr("Sería más fácil con el cofre cerrado.")


dialogId("tru-v-truhla1", "font_big", "Try to push its lid.")
dialogStr("Trata de empujar su tapa.")


dialogId("tru-m-vzit0", "font_small", "Won`t we take something with us?")
dialogStr("¿No vamos a llevar algo con nosotros?")


dialogId("tru-m-vzit1", "font_small", "What about taking some treasure with us?")
dialogStr("¿Que tal si tomamos algo del tesoro con nosotros?")


dialogId("tru-m-vzit2", "font_small", "Aren`t you sorry to leave all this treasure behind?")
dialogStr("¿No te apena dejar todos esos tesoros atrás?")


dialogId("tru-v-vzit0", "font_big", "We will be glad if we manage to get out ourselves.")
dialogStr("Estaremos felices si logramos salir nosotros mismos.")


dialogId("tru-v-vzit1", "font_big", "Don`t forget our mission.")
dialogStr("No olvidemos nuestra misión.")


dialogId("tru-v-vzit2", "font_big", "The treasure would only hinder us.")
dialogStr("El tesoro sólo nos obstaculizaría.")


dialogId("tru-v-zrak", "font_big", "All this glinting is a sight for the eyes.")
dialogStr("Toda esta fastuosidad es un espectáculo para la vista.")


dialogId("tru-m-trpyt", "font_small", "Everything here gleams so. It makes me dizzy.")
dialogStr("Todo aquí destella tanto. Me marea.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/chest/dialogs_es.lua <==

dialogId("tru-v-nasly", "font_big", "So we have finally found it.")
dialogStr("Así que finalmente lo hemos encontrado.")


dialogId("tru-m-co", "font_small", "What?")
dialogStr("¿Qué?")


dialogId("tru-v-poklad", "font_big", "Captain Silver’s treasure, of course.")
dialogStr("El tesoro del Capitán Silver, por supuesto.!")


dialogId("tru-v-gral", "font_big", "The Holy Grail, of course.")
dialogStr("El Santo Grial, por supuesto.")


dialogId("tru-v-vkupe", "font_big", "It’s neatly in one place: the treasure and the Grail.")
dialogStr("Están cuidadosamente en un mismo lugar: el tesoro y el Grial.")


dialogId("tru-m-zrada", "font_small", "I think it’s much too easy to be true.")
dialogStr("Creo que es demasiado fácil para ser verdad.")


dialogId("tru-m-oznamit", "font_small", "I think that if it really was our goal, the game would let the player know.")
dialogStr("Pienso que si realmente era nuestra meta, el juego dejaría que el jugador lo supiera.")


dialogId("tru-v-stacit", "font_big", "But I have let them know. That could be enough.")
dialogStr("Pero yo tengo que hacerles saber. Eso podría ser suficiente.")


dialogId("tru-m-zpochybnit", "font_small", "But I have casted doubts on it. This could confuse them.")
dialogStr("Pero he dicho las dudas a propósito. Esto los podría confundir.")


dialogId("tru-v-nejspis", "font_big", "Well, all right. PROBABLY this is not what we are looking for.")
dialogStr("Bueno, está bien. PROBABLEMENTE esto no es lo que andamos buscando.")


dialogId("tru-m-nejistota", "font_small", "That's better. There remains a bit of uncertainty.")
dialogStr("Eso es mejor. Le resta un poco de incertidumbre.")


dialogId("tru-m-truhla0", "font_small", "Couldn’t we close that chest?")
dialogStr("¿Podríamos acercar ese cofre?")


dialogId("tru-m-truhla1", "font_small", "What if we try to close that chest?")
dialogStr("¿Y si tratamos de acercar ese cofre?")


dialogId("tru-v-truhla0", "font_big", "It would be much easier with the chest closed.")
dialogStr("Sería más fácil con el cofre cerrado.")


dialogId("tru-v-truhla1", "font_big", "Try to push its lid.")
dialogStr("Trata de empujar su tapa.")


dialogId("tru-m-vzit0", "font_small", "Won’t we take something with us?")
dialogStr("¿No vamos a llevar algo con nosotros?")


dialogId("tru-m-vzit1", "font_small", "What about taking some treasure with us?")
dialogStr("¿Que tal si tomamos algo del tesoro con nosotros?")


dialogId("tru-m-vzit2", "font_small", "Aren’t you sorry to leave all this treasure behind?")
dialogStr("¿No te apena dejar todos esos tesoros atrás?")


dialogId("tru-v-vzit0", "font_big", "We will be glad if we manage to get out ourselves.")
dialogStr("Estaremos felices si logramos salir nosotros mismos.")


dialogId("tru-v-vzit1", "font_big", "Don’t forget our mission.")
dialogStr("No olvidemos nuestra misión.")


dialogId("tru-v-vzit2", "font_big", "The treasure would only hinder us.")
dialogStr("El tesoro sólo nos obstaculizaría.")


dialogId("tru-v-zrak", "font_big", "All this glinting is a sight for the eyes.")
dialogStr("Toda esta fastuosidad es un espectáculo para la vista.")


dialogId("tru-m-trpyt", "font_small", "Everything here gleams so. It makes me dizzy.")
dialogStr("Todo aquí destella tanto. Me marea.")
